@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: mplayer.pl,v 1.30 2006/08/10 09:02:50 khlut Exp $
+# $Id: mplayer.pl,v 1.31 2006/08/23 20:05:57 khlut Exp $
 # Bind mplayer and mencoder with HTML object
 # ElphelOgm is used to receive and record rtp mjpeg video
 #
@@ -127,7 +127,13 @@ $SIG{PIPE}=\&normal_exit;
 $SIG{ALRM}=\&shut;
 
 sub url2mplayer {
-    $v{href}=$v{baseURI}.'/'.$v{href}	if( $v{href}!~m|[a-zA-Z0-9]+:| );
+    if( $v{href} =~ m|^/| ) {
+	if($v{baseURI} !~ m|^file://| && $v{baseURI} =~ m|^[a-zA-Z0-9]+://[^/]/|) {
+	    $v{href}=$&.$v{href};
+	}
+    }else{
+	$v{href}=$v{baseURI}.'/'.$v{href}	if( $v{href}!~m|[a-zA-Z0-9]+:| );
+    }
     $href=$v{href};
     if($ENV{GENRES_MOZILLA_STREAMS} && $v{src} && $href=~m!^(http.?|ftp.?)://!) {
 	$href="/dev/fd/3";
